YARP 2.3.0 (2010-07-01)                                                {#v2_3_0}
=======================

Contributors
------------

This is a list of people that contributed to this release (generated from the
git history using `git shortlog -ens --no-merges v2.2.7...v2.3.0`):

```
   221	Paul Fitzpatrick <paulfitz@alum.mit.edu>
    23	Lorenzo Natale <lorenzo.natale@iit.it>
    16	Alessandro Scalzo <alessandro.scalzo@iit.it>
    11	Ugo Pattacini <ugo.pattacini@iit.it>
     2	Giacomo Spigler <spiglerg@gmail.com>
     1	Daniel Krieg <krieg@fias.uni-frankfurt.de>
     1	Jonas Ruesch <ruesch@ifi.uzh.ch>
     1	Marco Randazzo <marco.randazzo@iit.it>
```
